@@ -471,7 +471,7 @@ detect_package_manager_from_distribution() {
       package_installer="install_brew"
       tree="macos"
       if [ "${IGNORE_INSTALLED}" -eq 0 ] && [ -z "${brew}" ]; then
-        echo >&2 "command 'brew' is required to install packages on a '${distribution} ${version}' system."
+        echo >&2 "command 'brew' is required to install packages on a '${distribution} ${version}' system. Get instructions at https://brew.sh/"
         exit 1
       fi
       ;;
@@ -623,6 +623,12 @@ declare -A pkg_find=(
 
 declare -A pkg_distro_sdk=(
   ['alpine']="alpine-sdk"
+  ['centos']="kernel-headers"
+  ['default']="NOTREQUIRED"
+)
+
+declare -A pkg_coreutils=(
+  ['alpine']="coreutils"
   ['default']="NOTREQUIRED"
 )
 
@@ -747,6 +753,11 @@ declare -A pkg_libsystemd_dev=(
   ['default']="systemd-devel"
 )
 
+declare -A pkg_pcre2=(
+  ['macos']="pcre2"
+  ['default']="NOTREQUIRED"
+)
+
 declare -A pkg_bridge_utils=(
   ['gentoo']="net-misc/bridge-utils"
   ['clearlinux']="network-basic"
@@ -1228,6 +1239,7 @@ packages() {
   # basic build environment
 
   suitable_package distro-sdk
+  suitable_package coreutils
   suitable_package libatomic
 
   require_cmd git || suitable_package git
@@ -1303,6 +1315,7 @@ packages() {
     suitable_package fts-dev
     suitable_package libyaml-dev
     suitable_package libsystemd-dev
+    suitable_package pcre2
   fi
 
   # -------------------------------------------------------------------------
