@@ -3,12 +3,6 @@
 #include "libnetdata/libnetdata.h"
 #include "libnetdata/required_dummies.h"
 
-#ifdef HAVE_SETNS
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE             /* See feature_test_macros(7) */
-#endif
-#endif
-
 char env_netdata_host_prefix[FILENAME_MAX + 50] = "";
 char env_netdata_log_method[FILENAME_MAX + 50] = "";
 char env_netdata_log_format[FILENAME_MAX + 50] = "";
@@ -654,7 +648,6 @@ void usage(void) {
 int main(int argc, char **argv) {
     pid_t pid = 0;
 
-    program_version = VERSION;
     clocks_init();
     nd_log_initialize_for_external_plugins("cgroup-network");
 
@@ -692,7 +685,7 @@ int main(int argc, char **argv) {
     // ------------------------------------------------------------------------
 
     if(argc == 2 && (!strcmp(argv[1], "version") || !strcmp(argv[1], "-version") || !strcmp(argv[1], "--version") || !strcmp(argv[1], "-v") || !strcmp(argv[1], "-V"))) {
-        fprintf(stderr, "cgroup-network %s\n", VERSION);
+        fprintf(stderr, "cgroup-network %s\n", NETDATA_VERSION);
         exit(0);
     }
 
