@@ -6,8 +6,10 @@
 static char *fd_dimension_names[NETDATA_FD_SYSCALL_END] = { "open", "close" };
 static char *fd_id_names[NETDATA_FD_SYSCALL_END] = { "do_sys_open",  "__close_fd" };
 
+#ifdef LIBBPF_MAJOR_VERSION
 static char *close_targets[NETDATA_EBPF_MAX_FD_TARGETS] = {"close_fd", "__close_fd"};
 static char *open_targets[NETDATA_EBPF_MAX_FD_TARGETS] = {"do_sys_openat2", "do_sys_open"};
+#endif
 
 static netdata_syscall_stat_t fd_aggregated_data[NETDATA_FD_SYSCALL_END];
 static netdata_publish_syscall_t fd_publish_aggregated[NETDATA_FD_SYSCALL_END];
@@ -367,7 +369,7 @@ static void ebpf_obsolete_fd_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SYSCALL_APPS_FILE_OPEN,
                               "Number of open files",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_FILE_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
                               NETDATA_CGROUP_FD_OPEN_CONTEXT,
@@ -379,7 +381,7 @@ static void ebpf_obsolete_fd_services(ebpf_module_t *em, char *id)
                                   id,
                                   NETDATA_SYSCALL_APPS_FILE_OPEN_ERROR,
                                   "Fails to open files",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_FILE_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   NETDATA_CGROUP_FD_OPEN_ERR_CONTEXT,
@@ -391,7 +393,7 @@ static void ebpf_obsolete_fd_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SYSCALL_APPS_FILE_CLOSED,
                               "Files closed",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_FILE_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
                               NETDATA_CGROUP_FD_CLOSE_CONTEXT,
@@ -403,7 +405,7 @@ static void ebpf_obsolete_fd_services(ebpf_module_t *em, char *id)
                                   id,
                                   NETDATA_SYSCALL_APPS_FILE_CLOSE_ERROR,
                                   "Fails to close files",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_FILE_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   NETDATA_CGROUP_FD_CLOSE_ERR_CONTEXT,
@@ -455,7 +457,7 @@ void ebpf_obsolete_fd_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_file_open",
                                   "Number of open files",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_FILE_FDS,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_file_open",
@@ -467,7 +469,7 @@ void ebpf_obsolete_fd_apps_charts(struct ebpf_module *em)
                                       w->clean_name,
                                       "_ebpf_file_open_error",
                                       "Fails to open files.",
-                                      EBPF_COMMON_DIMENSION_CALL,
+                                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                       NETDATA_APPS_FILE_FDS,
                                       NETDATA_EBPF_CHART_TYPE_STACKED,
                                       "app.ebpf_file_open_error",
@@ -479,7 +481,7 @@ void ebpf_obsolete_fd_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_file_closed",
                                   "Files closed.",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_FILE_FDS,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_file_closed",
@@ -491,7 +493,7 @@ void ebpf_obsolete_fd_apps_charts(struct ebpf_module *em)
                                       w->clean_name,
                                       "_ebpf_file_close_error",
                                       "Fails to close files.",
-                                      EBPF_COMMON_DIMENSION_CALL,
+                                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                       NETDATA_APPS_FILE_FDS,
                                       NETDATA_EBPF_CHART_TYPE_STACKED,
                                       "app.ebpf_fd_close_error",
@@ -516,10 +518,10 @@ static void ebpf_obsolete_fd_global(ebpf_module_t *em)
                               NETDATA_FILE_OPEN_CLOSE_COUNT,
                               "",
                               "Open and close calls",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_FILE_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              NETDATA_FS_FILEDESCRIPTOR_CONTEXT,
                               NETDATA_CHART_PRIO_EBPF_FD_CHARTS,
                               em->update_every);
 
@@ -528,10 +530,10 @@ static void ebpf_obsolete_fd_global(ebpf_module_t *em)
                                   NETDATA_FILE_OPEN_ERR_COUNT,
                                   "",
                                   "Open fails",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_FILE_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_LINE,
-                                  NULL,
+                                  NETDATA_FS_FILEDESCRIPTOR_ERROR_CONTEXT,
                                   NETDATA_CHART_PRIO_EBPF_FD_CHARTS + 1,
                                   em->update_every);
     }
@@ -544,12 +546,13 @@ static void ebpf_obsolete_fd_global(ebpf_module_t *em)
  *
  * @param ptr thread data.
  */
-static void ebpf_fd_exit(void *ptr)
+static void ebpf_fd_exit(void *pptr)
 {
-    ebpf_module_t *em = (ebpf_module_t *)ptr;
+    ebpf_module_t *em = CLEANUP_FUNCTION_GET_PTR(pptr);
+    if(!em) return;
 
     if (ebpf_read_fd.thread)
-        netdata_thread_cancel(*ebpf_read_fd.thread);
+        nd_thread_signal_cancel(ebpf_read_fd.thread);
 
     if (em->enabled == NETDATA_THREAD_EBPF_FUNCTION_RUNNING) {
         pthread_mutex_lock(&lock);
@@ -771,13 +774,11 @@ void *ebpf_read_fd_thread(void *ptr)
     uint32_t running_time = 0;
     usec_t period = update_every * USEC_PER_SEC;
     int max_period = update_every * EBPF_CLEANUP_FACTOR;
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, period);
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
-        netdata_thread_disable_cancelability();
-
         pthread_mutex_lock(&collect_data_mutex);
         ebpf_read_fd_apps_table(maps_per_core, max_period);
         ebpf_fd_resume_apps_data();
@@ -793,7 +794,6 @@ void *ebpf_read_fd_thread(void *ptr)
 
         em->running_time = running_time;
         pthread_mutex_unlock(&ebpf_exit_cleanup);
-        netdata_thread_enable_cancelability();
     }
 
     return NULL;
@@ -904,42 +904,51 @@ static void ebpf_fd_sum_cgroup_pids(netdata_fd_stat_t *fd, struct pid_on_target2
  */
 static void ebpf_create_specific_fd_charts(char *type, ebpf_module_t *em)
 {
+    char *label = (!strncmp(type, "cgroup_", 7)) ? &type[7] : type;
     ebpf_create_chart(type, NETDATA_SYSCALL_APPS_FILE_OPEN, "Number of open files",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_APPS_FILE_GROUP,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_APPS_FILE_GROUP,
                       NETDATA_CGROUP_FD_OPEN_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5400,
                       ebpf_create_global_dimension,
                       &fd_publish_aggregated[NETDATA_FD_SYSCALL_OPEN],
                       1, em->update_every, NETDATA_EBPF_MODULE_NAME_FD);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     if (em->mode < MODE_ENTRY) {
         ebpf_create_chart(type, NETDATA_SYSCALL_APPS_FILE_OPEN_ERROR, "Fails to open files",
-                          EBPF_COMMON_DIMENSION_CALL, NETDATA_APPS_FILE_GROUP,
+                          EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_APPS_FILE_GROUP,
                           NETDATA_CGROUP_FD_OPEN_ERR_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                           NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5401,
                           ebpf_create_global_dimension,
                           &fd_publish_aggregated[NETDATA_FD_SYSCALL_OPEN],
                           1, em->update_every,
                           NETDATA_EBPF_MODULE_NAME_FD);
+        ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+        ebpf_commit_label();
     }
 
     ebpf_create_chart(type, NETDATA_SYSCALL_APPS_FILE_CLOSED, "Files closed",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_APPS_FILE_GROUP,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_APPS_FILE_GROUP,
                       NETDATA_CGROUP_FD_CLOSE_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5402,
                       ebpf_create_global_dimension,
                       &fd_publish_aggregated[NETDATA_FD_SYSCALL_CLOSE],
                       1, em->update_every, NETDATA_EBPF_MODULE_NAME_FD);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     if (em->mode < MODE_ENTRY) {
         ebpf_create_chart(type, NETDATA_SYSCALL_APPS_FILE_CLOSE_ERROR, "Fails to close files",
-                          EBPF_COMMON_DIMENSION_CALL, NETDATA_APPS_FILE_GROUP,
+                          EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_APPS_FILE_GROUP,
                           NETDATA_CGROUP_FD_CLOSE_ERR_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                           NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5403,
                           ebpf_create_global_dimension,
                           &fd_publish_aggregated[NETDATA_FD_SYSCALL_CLOSE],
                           1, em->update_every,
                           NETDATA_EBPF_MODULE_NAME_FD);
+        ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+        ebpf_commit_label();
     }
 }
 
@@ -954,25 +963,25 @@ static void ebpf_create_specific_fd_charts(char *type, ebpf_module_t *em)
 static void ebpf_obsolete_specific_fd_charts(char *type, ebpf_module_t *em)
 {
     ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_FILE_OPEN, "", "Number of open files",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_APPS_FILE_GROUP,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_APPS_FILE_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_FD_OPEN_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5400, em->update_every);
 
     if (em->mode < MODE_ENTRY) {
         ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_FILE_OPEN_ERROR, "", "Fails to open files",
-                                  EBPF_COMMON_DIMENSION_CALL, NETDATA_APPS_FILE_GROUP,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_APPS_FILE_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_FD_OPEN_ERR_CONTEXT,
                                   NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5401, em->update_every);
     }
 
     ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_FILE_CLOSED, "", "Files closed",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_APPS_FILE_GROUP,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_APPS_FILE_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_FD_CLOSE_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5402, em->update_every);
 
     if (em->mode < MODE_ENTRY) {
         ebpf_write_chart_obsolete(type, NETDATA_SYSCALL_APPS_FILE_CLOSE_ERROR, "", "Fails to close files",
-                                  EBPF_COMMON_DIMENSION_CALL, NETDATA_APPS_FILE_GROUP,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_APPS_FILE_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_FD_CLOSE_ERR_CONTEXT,
                                   NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5403, em->update_every);
     }
@@ -1020,10 +1029,10 @@ static void ebpf_create_systemd_fd_charts(ebpf_module_t *em)
 {
     static ebpf_systemd_args_t data_open = {
         .title = "Number of open files",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_FILE_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
-        .order = 20061,
+        .order = 20270,
         .algorithm = EBPF_CHART_ALGORITHM_INCREMENTAL,
         .context = NETDATA_SYSTEMD_FD_OPEN_CONTEXT,
         .module = NETDATA_EBPF_MODULE_NAME_FD,
@@ -1034,10 +1043,10 @@ static void ebpf_create_systemd_fd_charts(ebpf_module_t *em)
 
     static ebpf_systemd_args_t data_open_error = {
         .title = "Fails to open files",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_FILE_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
-        .order = 20062,
+        .order = 20271,
         .algorithm = EBPF_CHART_ALGORITHM_INCREMENTAL,
         .context = NETDATA_SYSTEMD_FD_OPEN_ERR_CONTEXT,
         .module = NETDATA_EBPF_MODULE_NAME_FD,
@@ -1048,10 +1057,10 @@ static void ebpf_create_systemd_fd_charts(ebpf_module_t *em)
 
     static ebpf_systemd_args_t data_close = {
         .title = "Files closed",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_FILE_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
-        .order = 20063,
+        .order = 20272,
         .algorithm = EBPF_CHART_ALGORITHM_INCREMENTAL,
         .context = NETDATA_SYSTEMD_FD_CLOSE_CONTEXT,
         .module = NETDATA_EBPF_MODULE_NAME_FD,
@@ -1062,10 +1071,10 @@ static void ebpf_create_systemd_fd_charts(ebpf_module_t *em)
 
     static ebpf_systemd_args_t data_close_error = {
         .title = "Fails to close files",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_FILE_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
-        .order = 20064,
+        .order = 20273,
         .algorithm = EBPF_CHART_ALGORITHM_INCREMENTAL,
         .context = NETDATA_SYSTEMD_FD_OPEN_ERR_CONTEXT,
         .module = NETDATA_EBPF_MODULE_NAME_FD,
@@ -1086,12 +1095,9 @@ static void ebpf_create_systemd_fd_charts(ebpf_module_t *em)
 
         data_open.id = data_open_error.id = data_close.id = data_close_error.id = w->name;
         ebpf_create_charts_on_systemd(&data_open);
-        if (mode < MODE_ENTRY) {
-            ebpf_create_charts_on_systemd(&data_open_error);
-        }
-
         ebpf_create_charts_on_systemd(&data_close);
         if (mode < MODE_ENTRY) {
+            ebpf_create_charts_on_systemd(&data_open_error);
             ebpf_create_charts_on_systemd(&data_close_error);
         }
 
@@ -1194,17 +1200,17 @@ static void fd_collector(ebpf_module_t *em)
     uint32_t lifetime = em->lifetime;
     netdata_idx_t *stats = em->hash_table_stats;
     memset(stats, 0, sizeof(em->hash_table_stats));
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, USEC_PER_SEC);
 
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
         counter = 0;
         netdata_apps_integration_flags_t apps = em->apps_charts;
         ebpf_fd_read_global_tables(stats, maps_per_core);
 
-        if (cgroups)
+        if (cgroups && shm_ebpf_cgroup.header)
             ebpf_update_fd_cgroup();
 
         pthread_mutex_lock(&lock);
@@ -1214,7 +1220,7 @@ static void fd_collector(ebpf_module_t *em)
         if (apps & NETDATA_EBPF_APPS_FLAG_CHART_CREATED)
             ebpf_fd_send_apps_data(em, apps_groups_root_target);
 
-        if (cgroups && shm_ebpf_cgroup.header && ebpf_cgroup_pids)
+        if (cgroups && shm_ebpf_cgroup.header)
             ebpf_fd_send_cgroup_data(em);
 
         pthread_mutex_unlock(&lock);
@@ -1256,14 +1262,14 @@ void ebpf_fd_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_file_open",
                              "Number of open files",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_APPS_FILE_FDS,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_file_open",
                              20220,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_FD);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -1272,14 +1278,14 @@ void ebpf_fd_create_apps_charts(struct ebpf_module *em, void *ptr)
                                  w->clean_name,
                                  "_ebpf_file_open_error",
                                  "Fails to open files.",
-                                 EBPF_COMMON_DIMENSION_CALL,
+                                 EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                  NETDATA_APPS_FILE_FDS,
                                  NETDATA_EBPF_CHART_TYPE_STACKED,
                                  "app.ebpf_file_open_error",
                                  20221,
                                  update_every,
                                  NETDATA_EBPF_MODULE_NAME_FD);
-            ebpf_create_chart_labels("app_group", w->name, 1);
+            ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
             ebpf_commit_label();
             fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
         }
@@ -1288,14 +1294,14 @@ void ebpf_fd_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_file_closed",
                              "Files closed.",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_APPS_FILE_FDS,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_file_closed",
                              20222,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_FD);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -1304,14 +1310,14 @@ void ebpf_fd_create_apps_charts(struct ebpf_module *em, void *ptr)
                                  w->clean_name,
                                  "_ebpf_file_close_error",
                                  "Fails to close files.",
-                                 EBPF_COMMON_DIMENSION_CALL,
+                                 EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                  NETDATA_APPS_FILE_FDS,
                                  NETDATA_EBPF_CHART_TYPE_STACKED,
                                  "app.ebpf_file_close_error",
                                  20223,
                                  update_every,
                                  NETDATA_EBPF_MODULE_NAME_FD);
-            ebpf_create_chart_labels("app_group", w->name, 1);
+            ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
             ebpf_commit_label();
             fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
         }
@@ -1334,9 +1340,9 @@ static void ebpf_create_fd_global_charts(ebpf_module_t *em)
     ebpf_create_chart(NETDATA_FILESYSTEM_FAMILY,
                       NETDATA_FILE_OPEN_CLOSE_COUNT,
                       "Open and close calls",
-                      EBPF_COMMON_DIMENSION_CALL,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                       NETDATA_FILE_GROUP,
-                      NULL,
+                      NETDATA_FS_FILEDESCRIPTOR_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_EBPF_FD_CHARTS,
                       ebpf_create_global_dimension,
@@ -1348,9 +1354,9 @@ static void ebpf_create_fd_global_charts(ebpf_module_t *em)
         ebpf_create_chart(NETDATA_FILESYSTEM_FAMILY,
                           NETDATA_FILE_OPEN_ERR_COUNT,
                           "Open fails",
-                          EBPF_COMMON_DIMENSION_CALL,
+                          EBPF_COMMON_UNITS_CALLS_PER_SEC,
                           NETDATA_FILE_GROUP,
-                          NULL,
+                          NETDATA_FS_FILEDESCRIPTOR_ERROR_CONTEXT,
                           NETDATA_EBPF_CHART_TYPE_LINE,
                           NETDATA_CHART_PRIO_EBPF_FD_CHARTS + 1,
                           ebpf_create_global_dimension,
@@ -1428,9 +1434,10 @@ static int ebpf_fd_load_bpf(ebpf_module_t *em)
  */
 void *ebpf_fd_thread(void *ptr)
 {
-    netdata_thread_cleanup_push(ebpf_fd_exit, ptr);
-
     ebpf_module_t *em = (ebpf_module_t *)ptr;
+
+    CLEANUP_FUNCTION_REGISTER(ebpf_fd_exit) cleanup_ptr = em;
+
     em->maps = fd_maps;
 
 #ifdef LIBBPF_MAJOR_VERSION
@@ -1456,18 +1463,12 @@ void *ebpf_fd_thread(void *ptr)
 
     pthread_mutex_unlock(&lock);
 
-    ebpf_read_fd.thread = mallocz(sizeof(netdata_thread_t));
-    netdata_thread_create(ebpf_read_fd.thread,
-                          ebpf_read_fd.name,
-                          NETDATA_THREAD_OPTION_DEFAULT,
-                          ebpf_read_fd_thread,
-                          em);
+    ebpf_read_fd.thread = nd_thread_create(ebpf_read_fd.name, NETDATA_THREAD_OPTION_DEFAULT, ebpf_read_fd_thread, em);
 
     fd_collector(em);
 
 endfd:
     ebpf_update_disabled_plugin_stats(em);
 
-    netdata_thread_cleanup_pop(1);
     return NULL;
 }
