@@ -291,10 +291,10 @@ static void ebpf_obsolete_shm_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SHMGET_CHART,
                               "Calls to syscall shmget(2).",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_IPC_SHM_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
-                              NULL,
+                              NETDATA_SYSTEMD_SHM_GET_CONTEXT,
                               20191,
                               em->update_every);
 
@@ -302,10 +302,10 @@ static void ebpf_obsolete_shm_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SHMAT_CHART,
                               "Calls to syscall shmat(2).",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_IPC_SHM_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
-                              NULL,
+                              NETDATA_SYSTEMD_SHM_AT_CONTEXT,
                               20192,
                               em->update_every);
 
@@ -313,10 +313,10 @@ static void ebpf_obsolete_shm_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SHMDT_CHART,
                               "Calls to syscall shmdt(2).",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_IPC_SHM_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
-                              NULL,
+                              NETDATA_SYSTEMD_SHM_DT_CONTEXT,
                               20193,
                               em->update_every);
 
@@ -324,11 +324,11 @@ static void ebpf_obsolete_shm_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_SHMCTL_CHART,
                               "Calls to syscall shmctl(2).",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_IPC_SHM_GROUP,
                               NETDATA_EBPF_CHART_TYPE_STACKED,
-                              NULL,
-                              20193,
+                              NETDATA_SYSTEMD_SHM_CTL_CONTEXT,
+                              20194,
                               em->update_every);
 }
 
@@ -375,7 +375,7 @@ void ebpf_obsolete_shm_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_shmget_call",
                                   "Calls to syscall shmget(2).",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_IPC_SHM_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_shmget_call",
@@ -386,7 +386,7 @@ void ebpf_obsolete_shm_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_shmat_call",
                                   "Calls to syscall shmat(2).",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_IPC_SHM_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_shmat_call",
@@ -397,7 +397,7 @@ void ebpf_obsolete_shm_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_shmdt_call",
                                   "Calls to syscall shmdt(2).",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_IPC_SHM_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_shmdt_call",
@@ -408,7 +408,7 @@ void ebpf_obsolete_shm_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_shmctl_call",
                                   "Calls to syscall shmctl(2).",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_APPS_IPC_SHM_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_shmctl_call",
@@ -433,10 +433,10 @@ static void ebpf_obsolete_shm_global(ebpf_module_t *em)
                               NETDATA_SHM_GLOBAL_CHART,
                               "",
                               "Calls to shared memory system calls",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_SYSTEM_IPC_SHM_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              "system.shared_memory_calls",
                               NETDATA_CHART_PRIO_SYSTEM_IPC_SHARED_MEM_CALLS,
                               em->update_every);
 }
@@ -448,12 +448,13 @@ static void ebpf_obsolete_shm_global(ebpf_module_t *em)
  *
  * @param ptr thread data.
  */
-static void ebpf_shm_exit(void *ptr)
+static void ebpf_shm_exit(void *pptr)
 {
-    ebpf_module_t *em = (ebpf_module_t *)ptr;
+    ebpf_module_t *em = CLEANUP_FUNCTION_GET_PTR(pptr);
+    if(!em) return;
 
     if (ebpf_read_shm.thread)
-        netdata_thread_cancel(*ebpf_read_shm.thread);
+        nd_thread_signal_cancel(ebpf_read_shm.thread);
 
     if (em->enabled == NETDATA_THREAD_EBPF_FUNCTION_RUNNING) {
         pthread_mutex_lock(&lock);
@@ -735,9 +736,10 @@ static void ebpf_shm_sum_cgroup_pids(netdata_publish_shm_t *shm, struct pid_on_t
  */
 static void ebpf_create_specific_shm_charts(char *type, int update_every)
 {
+    char *label = (!strncmp(type, "cgroup_", 7)) ? &type[7] : type;
     ebpf_create_chart(type, NETDATA_SHMGET_CHART,
                       "Calls to syscall shmget(2).",
-                      EBPF_COMMON_DIMENSION_CALL,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                       NETDATA_APPS_IPC_SHM_GROUP,
                       NETDATA_CGROUP_SHM_GET_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
@@ -747,10 +749,12 @@ static void ebpf_create_specific_shm_charts(char *type, int update_every)
                       1,
                       update_every,
                       NETDATA_EBPF_MODULE_NAME_SHM);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_SHMAT_CHART,
                       "Calls to syscall shmat(2).",
-                      EBPF_COMMON_DIMENSION_CALL,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                       NETDATA_APPS_IPC_SHM_GROUP,
                       NETDATA_CGROUP_SHM_AT_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
@@ -760,10 +764,12 @@ static void ebpf_create_specific_shm_charts(char *type, int update_every)
                       1,
                       update_every,
                       NETDATA_EBPF_MODULE_NAME_SHM);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_SHMDT_CHART,
                       "Calls to syscall shmdt(2).",
-                      EBPF_COMMON_DIMENSION_CALL,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                       NETDATA_APPS_IPC_SHM_GROUP,
                       NETDATA_CGROUP_SHM_DT_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
@@ -773,10 +779,12 @@ static void ebpf_create_specific_shm_charts(char *type, int update_every)
                       1,
                       update_every,
                       NETDATA_EBPF_MODULE_NAME_SHM);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_SHMCTL_CHART,
                       "Calls to syscall shmctl(2).",
-                      EBPF_COMMON_DIMENSION_CALL,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC,
                       NETDATA_APPS_IPC_SHM_GROUP,
                       NETDATA_CGROUP_SHM_CTL_CONTEXT,
                       NETDATA_EBPF_CHART_TYPE_LINE,
@@ -786,6 +794,8 @@ static void ebpf_create_specific_shm_charts(char *type, int update_every)
                       1,
                       update_every,
                       NETDATA_EBPF_MODULE_NAME_SHM);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 }
 
 /**
@@ -801,7 +811,7 @@ static void ebpf_obsolete_specific_shm_charts(char *type, int update_every)
     ebpf_write_chart_obsolete(type, NETDATA_SHMGET_CHART,
                               "",
                               "Calls to syscall shmget(2).",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_IPC_SHM_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_SHM_GET_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5800, update_every);
@@ -809,7 +819,7 @@ static void ebpf_obsolete_specific_shm_charts(char *type, int update_every)
     ebpf_write_chart_obsolete(type, NETDATA_SHMAT_CHART,
                               "",
                               "Calls to syscall shmat(2).",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_IPC_SHM_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_SHM_AT_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5801, update_every);
@@ -817,7 +827,7 @@ static void ebpf_obsolete_specific_shm_charts(char *type, int update_every)
     ebpf_write_chart_obsolete(type, NETDATA_SHMDT_CHART,
                               "",
                               "Calls to syscall shmdt(2).",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_IPC_SHM_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_SHM_DT_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5802, update_every);
@@ -825,7 +835,7 @@ static void ebpf_obsolete_specific_shm_charts(char *type, int update_every)
     ebpf_write_chart_obsolete(type, NETDATA_SHMCTL_CHART,
                               "",
                               "Calls to syscall shmctl(2).",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_APPS_IPC_SHM_GROUP,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_SHM_CTL_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5803, update_every);
@@ -842,7 +852,7 @@ static void ebpf_create_systemd_shm_charts(int update_every)
 {
     static ebpf_systemd_args_t data_shmget = {
         .title = "Calls to syscall shmget(2).",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_IPC_SHM_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20191,
@@ -856,7 +866,7 @@ static void ebpf_create_systemd_shm_charts(int update_every)
 
     static ebpf_systemd_args_t data_shmat = {
         .title = "Calls to syscall shmat(2).",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_IPC_SHM_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20192,
@@ -870,7 +880,7 @@ static void ebpf_create_systemd_shm_charts(int update_every)
 
     static ebpf_systemd_args_t data_shmdt = {
         .title = "Calls to syscall shmdt(2).",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_IPC_SHM_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20193,
@@ -884,7 +894,7 @@ static void ebpf_create_systemd_shm_charts(int update_every)
 
     static ebpf_systemd_args_t data_shmctl = {
         .title = "Calls to syscall shmctl(2).",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_APPS_IPC_SHM_GROUP,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20194,
@@ -1057,13 +1067,11 @@ void *ebpf_read_shm_thread(void *ptr)
     uint32_t running_time = 0;
     usec_t period = update_every * USEC_PER_SEC;
     int max_period = update_every * EBPF_CLEANUP_FACTOR;
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, period);
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
-        netdata_thread_disable_cancelability();
-
         pthread_mutex_lock(&collect_data_mutex);
         ebpf_read_shm_apps_table(maps_per_core, max_period);
         ebpf_shm_resume_apps_data();
@@ -1079,7 +1087,6 @@ void *ebpf_read_shm_thread(void *ptr)
 
         em->running_time = running_time;
         pthread_mutex_unlock(&ebpf_exit_cleanup);
-        netdata_thread_enable_cancelability();
     }
 
     return NULL;
@@ -1100,9 +1107,9 @@ static void shm_collector(ebpf_module_t *em)
     uint32_t lifetime = em->lifetime;
     netdata_idx_t *stats = em->hash_table_stats;
     memset(stats, 0, sizeof(em->hash_table_stats));
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, USEC_PER_SEC);
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
         counter = 0;
@@ -1110,7 +1117,7 @@ static void shm_collector(ebpf_module_t *em)
         ebpf_shm_read_global_table(stats, maps_per_core);
         pthread_mutex_lock(&lock);
 
-        if (cgroups) {
+        if (cgroups && shm_ebpf_cgroup.header) {
             ebpf_update_shm_cgroup();
         }
 
@@ -1120,7 +1127,7 @@ static void shm_collector(ebpf_module_t *em)
             ebpf_shm_send_apps_data(apps_groups_root_target);
         }
 
-        if (cgroups) {
+        if (cgroups && shm_ebpf_cgroup.header) {
             ebpf_shm_send_cgroup_data(update_every);
         }
 
@@ -1161,14 +1168,14 @@ void ebpf_shm_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_shmget_call",
                              "Calls to syscall shmget(2).",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_APPS_IPC_SHM_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_shmget_call",
                              20191,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_SHM);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -1176,14 +1183,14 @@ void ebpf_shm_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_shmat_call",
                              "Calls to syscall shmat(2).",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_APPS_IPC_SHM_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_shmat_call",
                              20192,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_SHM);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -1191,14 +1198,14 @@ void ebpf_shm_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_shmdt_call",
                              "Calls to syscall shmdt(2).",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_APPS_IPC_SHM_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_shmdt_call",
                              20193,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_SHM);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -1206,14 +1213,14 @@ void ebpf_shm_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_shmctl_call",
                              "Calls to syscall shmctl(2).",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_APPS_IPC_SHM_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_shmctl_call",
                              20194,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_SHM);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -1257,9 +1264,9 @@ static void ebpf_create_shm_charts(int update_every)
         NETDATA_EBPF_SYSTEM_GROUP,
         NETDATA_SHM_GLOBAL_CHART,
         "Calls to shared memory system calls",
-        EBPF_COMMON_DIMENSION_CALL,
+        EBPF_COMMON_UNITS_CALLS_PER_SEC,
         NETDATA_SYSTEM_IPC_SHM_SUBMENU,
-        NULL,
+        "system.shared_memory_calls",
         NETDATA_EBPF_CHART_TYPE_LINE,
         NETDATA_CHART_PRIO_SYSTEM_IPC_SHARED_MEM_CALLS,
         ebpf_create_global_dimension,
@@ -1318,9 +1325,10 @@ static int ebpf_shm_load_bpf(ebpf_module_t *em)
  */
 void *ebpf_shm_thread(void *ptr)
 {
-    netdata_thread_cleanup_push(ebpf_shm_exit, ptr);
-
     ebpf_module_t *em = (ebpf_module_t *)ptr;
+
+    CLEANUP_FUNCTION_REGISTER(ebpf_shm_exit) cleanup_ptr = em;
+
     em->maps = shm_maps;
 
     ebpf_update_pid_table(&shm_maps[NETDATA_PID_SHM_TABLE], em);
@@ -1355,18 +1363,12 @@ void *ebpf_shm_thread(void *ptr)
     ebpf_update_kernel_memory_with_vector(&plugin_statistics, em->maps, EBPF_ACTION_STAT_ADD);
     pthread_mutex_unlock(&lock);
 
-    ebpf_read_shm.thread = mallocz(sizeof(netdata_thread_t));
-    netdata_thread_create(ebpf_read_shm.thread,
-                          ebpf_read_shm.name,
-                          NETDATA_THREAD_OPTION_DEFAULT,
-                          ebpf_read_shm_thread,
-                          em);
+    ebpf_read_shm.thread = nd_thread_create(ebpf_read_shm.name, NETDATA_THREAD_OPTION_DEFAULT, ebpf_read_shm_thread, em);
 
     shm_collector(em);
 
 endshm:
     ebpf_update_disabled_plugin_stats(em);
 
-    netdata_thread_cleanup_pop(1);
     return NULL;
 }
