@@ -48,10 +48,13 @@ static ebpf_local_maps_t swap_maps[] = {{.name = "tbl_pid_swap", .internal_input
 #endif
                                         }};
 
-netdata_ebpf_targets_t swap_targets[] = { {.name = "swap_readpage", .mode = EBPF_LOAD_TRAMPOLINE},
+netdata_ebpf_targets_t swap_targets[] = { {.name = NULL, .mode = EBPF_LOAD_TRAMPOLINE},
                                            {.name = "swap_writepage", .mode = EBPF_LOAD_TRAMPOLINE},
                                            {.name = NULL, .mode = EBPF_LOAD_TRAMPOLINE}};
 
+static char *swap_read[] ={ "swap_readpage", "swap_read_folio", NULL };
+
+
 struct netdata_static_thread ebpf_read_swap = {
     .name = "EBPF_READ_SWAP",
     .config_section = NULL,
@@ -74,9 +77,27 @@ struct netdata_static_thread ebpf_read_swap = {
 static void ebpf_swap_disable_probe(struct swap_bpf *obj)
 {
     bpf_program__set_autoload(obj->progs.netdata_swap_readpage_probe, false);
+    bpf_program__set_autoload(obj->progs.netdata_swap_read_folio_probe, false);
     bpf_program__set_autoload(obj->progs.netdata_swap_writepage_probe, false);
 }
 
+/**
+ * Disable specific probe
+ *
+ * Disable specific probes according to available functions
+ *
+ * @param obj is the main structure for bpf objects
+ */
+static inline void ebpf_swap_disable_specific_probe(struct swap_bpf *obj)
+{
+    if (!strcmp(swap_targets[NETDATA_KEY_SWAP_READPAGE_CALL].name,
+                swap_read[NETDATA_KEY_SWAP_READPAGE_CALL])) {
+        bpf_program__set_autoload(obj->progs.netdata_swap_read_folio_probe, false);
+    } else  {
+        bpf_program__set_autoload(obj->progs.netdata_swap_readpage_probe, false);
+    }
+}
+
 /*
  * Disable trampoline
  *
@@ -87,9 +108,27 @@ static void ebpf_swap_disable_probe(struct swap_bpf *obj)
 static void ebpf_swap_disable_trampoline(struct swap_bpf *obj)
 {
     bpf_program__set_autoload(obj->progs.netdata_swap_readpage_fentry, false);
+    bpf_program__set_autoload(obj->progs.netdata_swap_read_folio_fentry, false);
     bpf_program__set_autoload(obj->progs.netdata_swap_writepage_fentry, false);
 }
 
+/**
+ * Disable specific trampoline
+ *
+ * Disable specific trampolines according to available functions
+ *
+ * @param obj is the main structure for bpf objects
+ */
+static inline void ebpf_swap_disable_specific_trampoline(struct swap_bpf *obj)
+{
+    if (!strcmp(swap_targets[NETDATA_KEY_SWAP_READPAGE_CALL].name,
+                swap_read[NETDATA_KEY_SWAP_READPAGE_CALL])) {
+        bpf_program__set_autoload(obj->progs.netdata_swap_read_folio_fentry, false);
+    } else  {
+        bpf_program__set_autoload(obj->progs.netdata_swap_readpage_fentry, false);
+    }
+}
+
 /**
  * Set trampoline target
  *
@@ -117,10 +156,19 @@ static void ebpf_swap_set_trampoline_target(struct swap_bpf *obj)
  */
 static int ebpf_swap_attach_kprobe(struct swap_bpf *obj)
 {
-    obj->links.netdata_swap_readpage_probe = bpf_program__attach_kprobe(obj->progs.netdata_swap_readpage_probe,
-                                                                        false,
-                                                                        swap_targets[NETDATA_KEY_SWAP_READPAGE_CALL].name);
-    int ret = libbpf_get_error(obj->links.netdata_swap_readpage_probe);
+    int ret;
+    if (!strcmp(swap_targets[NETDATA_KEY_SWAP_READPAGE_CALL].name,
+                swap_read[NETDATA_KEY_SWAP_READPAGE_CALL])) {
+        obj->links.netdata_swap_readpage_probe = bpf_program__attach_kprobe(obj->progs.netdata_swap_readpage_probe,
+                                                                            false,
+                                                                            swap_targets[NETDATA_KEY_SWAP_READPAGE_CALL].name);
+        ret = libbpf_get_error(obj->links.netdata_swap_readpage_probe);
+    } else {
+        obj->links.netdata_swap_read_folio_probe = bpf_program__attach_kprobe(obj->progs.netdata_swap_read_folio_probe,
+                                                                            false,
+                                                                            swap_targets[NETDATA_KEY_SWAP_READPAGE_CALL].name);
+        ret = libbpf_get_error(obj->links.netdata_swap_read_folio_probe);
+    }
     if (ret)
         return -1;
 
@@ -183,10 +231,12 @@ static inline int ebpf_swap_load_and_attach(struct swap_bpf *obj, ebpf_module_t
 
     if (test == EBPF_LOAD_TRAMPOLINE) {
         ebpf_swap_disable_probe(obj);
+	ebpf_swap_disable_specific_trampoline(obj);
 
         ebpf_swap_set_trampoline_target(obj);
     } else {
         ebpf_swap_disable_trampoline(obj);
+	ebpf_swap_disable_specific_probe(obj);
     }
 
     ebpf_swap_adjust_map(obj, em);
@@ -228,22 +278,22 @@ static void ebpf_obsolete_swap_services(ebpf_module_t *em, char *id)
                               id,
                               NETDATA_MEM_SWAP_READ_CHART,
                               "Calls to function swap_readpage.",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_SYSTEM_SWAP_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NETDATA_CGROUP_SWAP_READ_CONTEXT,
-                              NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5100,
+                              NETDATA_SYSTEMD_SWAP_READ_CONTEXT,
+                              20191,
                               em->update_every);
 
     ebpf_write_chart_obsolete(NETDATA_SERVICE_FAMILY,
                               id,
                               NETDATA_MEM_SWAP_WRITE_CHART,
                               "Calls to function swap_writepage.",
-                              EBPF_COMMON_DIMENSION_CALL,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC,
                               NETDATA_SYSTEM_SWAP_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
                               NETDATA_CGROUP_SWAP_WRITE_CONTEXT,
-                              NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5101,
+                              20192,
                               em->update_every);
 }
 
@@ -290,7 +340,7 @@ void ebpf_obsolete_swap_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_call_swap_readpage",
                                   "Calls to function swap_readpage.",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_EBPF_MEMORY_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_call_swap_readpage",
@@ -301,7 +351,7 @@ void ebpf_obsolete_swap_apps_charts(struct ebpf_module *em)
                                   w->clean_name,
                                   "_ebpf_call_swap_writepage",
                                   "Calls to function swap_writepage.",
-                                  EBPF_COMMON_DIMENSION_CALL,
+                                  EBPF_COMMON_UNITS_CALLS_PER_SEC,
                                   NETDATA_EBPF_MEMORY_GROUP,
                                   NETDATA_EBPF_CHART_TYPE_STACKED,
                                   "app.ebpf_call_swap_writepage",
@@ -325,9 +375,9 @@ static void ebpf_obsolete_swap_global(ebpf_module_t *em)
                               NETDATA_MEM_SWAP_CHART,
                               "",
                               "Calls to access swap memory",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_SYSTEM_SWAP_SUBMENU,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_SYSTEM_SWAP_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE,
-                              NULL,
+                              "mem.swapcalls",
                               NETDATA_CHART_PRIO_MEM_SWAP_CALLS,
                               em->update_every);
 }
@@ -344,7 +394,7 @@ static void ebpf_swap_exit(void *ptr)
     ebpf_module_t *em = (ebpf_module_t *)ptr;
 
     if (ebpf_read_swap.thread)
-        netdata_thread_cancel(*ebpf_read_swap.thread);
+        nd_thread_signal_cancel(ebpf_read_swap.thread);
 
     if (em->enabled == NETDATA_THREAD_EBPF_FUNCTION_RUNNING) {
         pthread_mutex_lock(&lock);
@@ -545,13 +595,11 @@ void *ebpf_read_swap_thread(void *ptr)
     usec_t period = update_every * USEC_PER_SEC;
     int max_period = update_every * EBPF_CLEANUP_FACTOR;
 
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, period);
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
-        netdata_thread_disable_cancelability();
-
         pthread_mutex_lock(&collect_data_mutex);
         ebpf_read_swap_apps_table(maps_per_core, max_period);
         ebpf_swap_resume_apps_data();
@@ -567,7 +615,6 @@ void *ebpf_read_swap_thread(void *ptr)
 
         em->running_time = running_time;
         pthread_mutex_unlock(&ebpf_exit_cleanup);
-        netdata_thread_enable_cancelability();
     }
 
     return NULL;
@@ -695,22 +742,27 @@ static void ebpf_send_systemd_swap_charts()
  */
 static void ebpf_create_specific_swap_charts(char *type, int update_every)
 {
+    char *label = (!strncmp(type, "cgroup_", 7)) ? &type[7] : type;
     ebpf_create_chart(type, NETDATA_MEM_SWAP_READ_CHART,
                       "Calls to function swap_readpage.",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_SYSTEM_SWAP_SUBMENU,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_SYSTEM_SWAP_SUBMENU,
                       NETDATA_CGROUP_SWAP_READ_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5100,
                       ebpf_create_global_dimension,
                       swap_publish_aggregated, 1, update_every, NETDATA_EBPF_MODULE_NAME_SWAP);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 
     ebpf_create_chart(type, NETDATA_MEM_SWAP_WRITE_CHART,
                       "Calls to function swap_writepage.",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_SYSTEM_SWAP_SUBMENU,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_SYSTEM_SWAP_SUBMENU,
                       NETDATA_CGROUP_SWAP_WRITE_CONTEXT, NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5101,
                       ebpf_create_global_dimension,
                       &swap_publish_aggregated[NETDATA_KEY_SWAP_WRITEPAGE_CALL], 1,
                       update_every, NETDATA_EBPF_MODULE_NAME_SWAP);
+    ebpf_create_chart_labels("cgroup_name", label, RRDLABEL_SRC_AUTO);
+    ebpf_commit_label();
 }
 
 /**
@@ -724,12 +776,12 @@ static void ebpf_create_specific_swap_charts(char *type, int update_every)
 static void ebpf_obsolete_specific_swap_charts(char *type, int update_every)
 {
     ebpf_write_chart_obsolete(type, NETDATA_MEM_SWAP_READ_CHART, "", "Calls to function swap_readpage.",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_SYSTEM_SWAP_SUBMENU,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_SYSTEM_SWAP_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_SWAP_READ_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5100, update_every);
 
     ebpf_write_chart_obsolete(type, NETDATA_MEM_SWAP_WRITE_CHART, "",  "Calls to function swap_writepage.",
-                              EBPF_COMMON_DIMENSION_CALL, NETDATA_SYSTEM_SWAP_SUBMENU,
+                              EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_SYSTEM_SWAP_SUBMENU,
                               NETDATA_EBPF_CHART_TYPE_LINE, NETDATA_CGROUP_SWAP_WRITE_CONTEXT,
                               NETDATA_CHART_PRIO_CGROUPS_CONTAINERS + 5101, update_every);
 }
@@ -763,8 +815,8 @@ static void ebpf_send_specific_swap_data(char *type, netdata_publish_swap_t *val
 static void ebpf_create_systemd_swap_charts(int update_every)
 {
     static ebpf_systemd_args_t data_read = {
-        .title = "Calls to swap_readpage.",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .title = "Calls to function swap_readpage.",
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_SYSTEM_SWAP_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20191,
@@ -778,7 +830,7 @@ static void ebpf_create_systemd_swap_charts(int update_every)
 
     static ebpf_systemd_args_t data_write = {
         .title = "Calls to function swap_writepage.",
-        .units = EBPF_COMMON_DIMENSION_CALL,
+        .units = EBPF_COMMON_UNITS_CALLS_PER_SEC,
         .family = NETDATA_SYSTEM_SWAP_SUBMENU,
         .charttype = NETDATA_EBPF_CHART_TYPE_STACKED,
         .order = 20192,
@@ -865,16 +917,16 @@ static void swap_collector(ebpf_module_t *em)
     uint32_t lifetime = em->lifetime;
     netdata_idx_t *stats = em->hash_table_stats;
     memset(stats, 0, sizeof(em->hash_table_stats));
-    while (!ebpf_plugin_exit && running_time < lifetime) {
+    while (!ebpf_plugin_stop() && running_time < lifetime) {
         (void)heartbeat_next(&hb, USEC_PER_SEC);
-        if (ebpf_plugin_exit || ++counter != update_every)
+        if (ebpf_plugin_stop() || ++counter != update_every)
             continue;
 
         counter = 0;
         netdata_apps_integration_flags_t apps = em->apps_charts;
         ebpf_swap_read_global_table(stats, maps_per_core);
 
-        if (cgroup)
+        if (cgroup && shm_ebpf_cgroup.header)
             ebpf_update_swap_cgroup();
 
         pthread_mutex_lock(&lock);
@@ -884,7 +936,7 @@ static void swap_collector(ebpf_module_t *em)
         if (apps & NETDATA_EBPF_APPS_FLAG_CHART_CREATED)
             ebpf_swap_send_apps_data(apps_groups_root_target);
 
-        if (cgroup && shm_ebpf_cgroup.header && ebpf_cgroup_pids)
+        if (cgroup && shm_ebpf_cgroup.header)
             ebpf_swap_send_cgroup_data(update_every);
 
         pthread_mutex_unlock(&lock);
@@ -926,14 +978,14 @@ void ebpf_swap_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_call_swap_readpage",
                              "Calls to function swap_readpage.",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_EBPF_MEMORY_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_call_swap_readpage",
                              20070,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_SWAP);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -941,14 +993,14 @@ void ebpf_swap_create_apps_charts(struct ebpf_module *em, void *ptr)
                              w->clean_name,
                              "_ebpf_call_swap_writepage",
                              "Calls to function swap_writepage.",
-                             EBPF_COMMON_DIMENSION_CALL,
+                             EBPF_COMMON_UNITS_CALLS_PER_SEC,
                              NETDATA_EBPF_MEMORY_GROUP,
                              NETDATA_EBPF_CHART_TYPE_STACKED,
                              "app.ebpf_call_swap_writepage",
                              20071,
                              update_every,
                              NETDATA_EBPF_MODULE_NAME_SWAP);
-        ebpf_create_chart_labels("app_group", w->name, 1);
+        ebpf_create_chart_labels("app_group", w->name, RRDLABEL_SRC_AUTO);
         ebpf_commit_label();
         fprintf(stdout, "DIMENSION calls '' %s 1 1\n", ebpf_algorithms[NETDATA_EBPF_INCREMENTAL_IDX]);
 
@@ -989,8 +1041,8 @@ static void ebpf_create_swap_charts(int update_every)
 {
     ebpf_create_chart(NETDATA_EBPF_MEMORY_GROUP, NETDATA_MEM_SWAP_CHART,
                       "Calls to access swap memory",
-                      EBPF_COMMON_DIMENSION_CALL, NETDATA_SYSTEM_SWAP_SUBMENU,
-                      NULL,
+                      EBPF_COMMON_UNITS_CALLS_PER_SEC, NETDATA_SYSTEM_SWAP_SUBMENU,
+                      "mem.swapcalls",
                       NETDATA_EBPF_CHART_TYPE_LINE,
                       NETDATA_CHART_PRIO_MEM_SWAP_CALLS,
                       ebpf_create_global_dimension,
@@ -1037,6 +1089,34 @@ static int ebpf_swap_load_bpf(ebpf_module_t *em)
     return ret;
 }
 
+/**
+ * Update Internal value
+ *
+ * Update values used during runtime.
+ *
+ * @return It returns 0 when one of the functions is present and -1 otherwise.
+ */
+static int ebpf_swap_set_internal_value()
+{
+    ebpf_addresses_t address = {.function = NULL, .hash = 0, .addr = 0};
+    int i;
+    for (i = 0; swap_read[i] ; i++) {
+        address.function = swap_read[i];
+        ebpf_load_addresses(&address, -1);
+        if (address.addr)
+            break;
+    }
+
+    if (!address.addr) {
+        netdata_log_error("%s swap.", NETDATA_EBPF_DEFAULT_FNT_NOT_FOUND);
+        return -1;
+    }
+
+    swap_targets[NETDATA_KEY_SWAP_READPAGE_CALL].name = address.function;
+
+    return 0;
+}
+
 /**
  * SWAP thread
  *
@@ -1048,13 +1128,18 @@ static int ebpf_swap_load_bpf(ebpf_module_t *em)
  */
 void *ebpf_swap_thread(void *ptr)
 {
-    netdata_thread_cleanup_push(ebpf_swap_exit, ptr);
-
     ebpf_module_t *em = (ebpf_module_t *)ptr;
+
+    CLEANUP_FUNCTION_REGISTER(ebpf_swap_exit) cleanup_ptr = em;
+
     em->maps = swap_maps;
 
     ebpf_update_pid_table(&swap_maps[NETDATA_PID_SWAP_TABLE], em);
 
+    if (ebpf_swap_set_internal_value()) {
+        goto endswap;
+    }
+
 #ifdef LIBBPF_MAJOR_VERSION
     ebpf_adjust_thread_load(em, default_btf);
 #endif
@@ -1074,18 +1159,13 @@ void *ebpf_swap_thread(void *ptr)
     ebpf_update_kernel_memory_with_vector(&plugin_statistics, em->maps, EBPF_ACTION_STAT_ADD);
     pthread_mutex_unlock(&lock);
 
-    ebpf_read_swap.thread = mallocz(sizeof(netdata_thread_t));
-    netdata_thread_create(ebpf_read_swap.thread,
-                          ebpf_read_swap.name,
-                          NETDATA_THREAD_OPTION_DEFAULT,
-                          ebpf_read_swap_thread,
-                          em);
+    ebpf_read_swap.thread = nd_thread_create(ebpf_read_swap.name, NETDATA_THREAD_OPTION_DEFAULT,
+                                             ebpf_read_swap_thread, em);
 
     swap_collector(em);
 
 endswap:
     ebpf_update_disabled_plugin_stats(em);
 
-    netdata_thread_cleanup_pop(1);
     return NULL;
 }
