@@ -1693,114 +1693,3 @@ error:
     fprintf(stderr,"SQLite tests failed\n");
     return 1;
 }
-
-static int bitmapX_test(BITMAPX *ptr, char *expected, const char *msg) {
-    int errors = 0;
-
-    for(uint32_t idx = 0; idx < ptr->bits ; idx++) {
-        bool found_set = bitmapX_get_bit(ptr, idx);
-        bool expected_set = expected[idx];
-
-        if(found_set != expected_set) {
-            fprintf(stderr, " >>> %s(): %s, bit %u is expected %s but found %s\n",
-                    __FUNCTION__, msg, idx, expected_set?"SET":"UNSET", found_set?"SET":"UNSET");
-            errors++;
-        }
-    }
-
-    if(errors)
-        fprintf(stderr,"%s(): %s, found %d errors\n",
-                __FUNCTION__, msg, errors);
-
-    return errors;
-}
-
-#define bitmapX_set_bit_and_track(ptr, bit, value, expected) do { \
-    bitmapX_set_bit(ptr, bit, value);                             \
-    (expected)[bit] = value;                                      \
-} while(0)
-
-int unit_test_bitmaps(void) {
-    fprintf(stderr, "%s() running...\n", __FUNCTION__ );
-
-    int errors = 0;
-
-    char expected[8192];
-
-    BITMAP256 bmp256 = BITMAP256_INITIALIZER;
-    BITMAP1024 bmp1024 = BITMAP1024_INITIALIZER;
-    BITMAPX *bmp = NULL;
-
-    for(int x = 0; x < 3 ; x++) {
-        char msg[100 + 1];
-
-        switch (x) {
-            default:
-            case 0:
-                bmp = (BITMAPX *) &bmp256;
-                break;
-
-            case 1:
-                bmp = (BITMAPX *) &bmp1024;
-                break;
-
-            case 2:
-                bmp = bitmapX_create(8192);
-                break;
-        }
-
-        // reset
-        memset(expected, 0, bmp->bits);
-        memset(bmp->data, 0, bmp->bits / 8);
-
-        snprintf(msg, 100, "TEST 1 BITMAP %u", bmp->bits);
-        bitmapX_set_bit_and_track(bmp, 0, true, expected);
-        errors += bitmapX_test(bmp, expected, msg);
-
-        snprintf(msg, 100, "TEST 2 BITMAP %u", bmp->bits);
-        bitmapX_set_bit_and_track(bmp, 64, true, expected);
-        errors += bitmapX_test(bmp, expected, msg);
-
-        snprintf(msg, 100, "TEST 3 BITMAP %u", bmp->bits);
-        bitmapX_set_bit_and_track(bmp, 128, true, expected);
-        errors += bitmapX_test(bmp, expected, msg);
-
-        snprintf(msg, 100, "TEST 4 BITMAP %u", bmp->bits);
-        bitmapX_set_bit_and_track(bmp, 192, true, expected);
-        errors += bitmapX_test(bmp, expected, msg);
-
-        for (uint32_t step = 1; step < 256; step++) {
-            snprintf(msg, 100, "TEST 5 (setting) BITMAP %u STEP %u", bmp->bits, step);
-
-            // reset
-            memset(expected, 0, bmp->bits);
-            memset(bmp->data, 0, bmp->bits / 8);
-
-            for (uint32_t i = 0; i < bmp->bits ; i += step)
-                bitmapX_set_bit_and_track(bmp, i, true, expected);
-
-            errors += bitmapX_test(bmp, expected, msg);
-        }
-
-        for (uint32_t step = 1; step < 256; step++) {
-            snprintf(msg, 100, "TEST 6 (clearing) BITMAP %u STEP %u", bmp->bits, step);
-
-            // reset
-            memset(expected, 0, bmp->bits);
-            memset(bmp->data, 0, bmp->bits / 8);
-
-            for (uint32_t i = 0; i < bmp->bits ; i++)
-                bitmapX_set_bit_and_track(bmp, i, true, expected);
-
-            for (uint32_t i = 0; i < bmp->bits ; i += step)
-                bitmapX_set_bit_and_track(bmp, i, false, expected);
-
-            errors += bitmapX_test(bmp, expected, msg);
-        }
-    }
-
-    freez(bmp);
-
-    fprintf(stderr, "%s() %d errors\n", __FUNCTION__, errors);
-    return errors;
-}
