@@ -21,6 +21,7 @@ void sanity_check(void) {
     BUILD_BUG_ON(WORKER_UTILIZATION_MAX_JOB_TYPES < ACLK_MAX_ENUMERATIONS_DEFINED);
 }
 
+#ifdef ENABLE_ACLK
 static struct aclk_database_cmd aclk_database_deq_cmd(void)
 {
     struct aclk_database_cmd ret;
@@ -40,6 +41,7 @@ static struct aclk_database_cmd aclk_database_deq_cmd(void)
 
     return ret;
 }
+#endif
 
 static void aclk_database_enq_cmd(struct aclk_database_cmd *cmd)
 {
@@ -97,7 +99,7 @@ static int create_host_callback(void *data, int argc, char **argv, char **column
         is_registered = str2i(argv[IDX_IS_REGISTERED]);
 
     char guid[UUID_STR_LEN];
-    uuid_unparse_lower(*(uuid_t *)argv[IDX_HOST_ID], guid);
+    uuid_unparse_lower(*(nd_uuid_t *)argv[IDX_HOST_ID], guid);
 
     if (is_ephemeral && age > rrdhost_free_ephemeral_time_s) {
         netdata_log_info(
@@ -116,7 +118,7 @@ static int create_host_callback(void *data, int argc, char **argv, char **column
 
     system_info->hops = str2i((const char *) argv[IDX_HOPS]);
 
-    sql_build_host_system_info((uuid_t *)argv[IDX_HOST_ID], system_info);
+    sql_build_host_system_info((nd_uuid_t *)argv[IDX_HOST_ID], system_info);
 
     RRDHOST *host = rrdhost_find_or_create(
         (const char *)argv[IDX_HOSTNAME],
@@ -157,7 +159,7 @@ static int create_host_callback(void *data, int argc, char **argv, char **column
         if (is_ephemeral)
             host->child_disconnected_time = now_realtime_sec();
 
-        host->rrdlabels = sql_load_host_labels((uuid_t *)argv[IDX_HOST_ID]);
+        host->rrdlabels = sql_load_host_labels((nd_uuid_t *)argv[IDX_HOST_ID]);
         host->last_connected = last_connected;
     }
 
@@ -175,34 +177,26 @@ static int create_host_callback(void *data, int argc, char **argv, char **column
 #ifdef ENABLE_ACLK
 
 #define SQL_SELECT_HOST_BY_UUID  "SELECT host_id FROM host WHERE host_id = @host_id"
-static int is_host_available(uuid_t *host_id)
+static int is_host_available(nd_uuid_t *host_id)
 {
     sqlite3_stmt *res = NULL;
-    int rc;
+    int rc = 0;
 
-    if (unlikely(!db_meta)) {
-        if (default_rrd_memory_mode == RRD_MEMORY_MODE_DBENGINE)
-            error_report("Database has not been initialized");
+    if (!REQUIRE_DB(db_meta))
         return 1;
-    }
 
-    rc = sqlite3_prepare_v2(db_meta, SQL_SELECT_HOST_BY_UUID, -1, &res, 0);
-    if (unlikely(rc != SQLITE_OK)) {
-        error_report("Failed to prepare statement to select node instance information for a node");
+    if (!PREPARE_STATEMENT(db_meta, SQL_SELECT_HOST_BY_UUID, &res))
         return 1;
-    }
 
-    rc = sqlite3_bind_blob(res, 1, host_id, sizeof(*host_id), SQLITE_STATIC);
-    if (unlikely(rc != SQLITE_OK)) {
-        error_report("Failed to bind host_id parameter to check host existence");
-        goto failed;
-    }
+    int param = 0;
+    SQLITE_BIND_FAIL(done, sqlite3_bind_blob(res, ++param, host_id, sizeof(*host_id), SQLITE_STATIC));
+
+    param = 0;
     rc = sqlite3_step_monitored(res);
 
-failed:
-    if (unlikely(sqlite3_finalize(res) != SQLITE_OK))
-        error_report("Failed to finalize the prepared statement when checking host existence");
-
+done:
+    REPORT_BIND_FAIL(res, param);
+    SQLITE_FINALIZE(res);
     return (rc == SQLITE_ROW);
 }
 
@@ -213,7 +207,7 @@ static void sql_delete_aclk_table_list(char *host_guid)
     char host_str[UUID_STR_LEN];
 
     int rc;
-    uuid_t host_uuid;
+    nd_uuid_t host_uuid;
 
     if (unlikely(!host_guid))
         return;
@@ -235,19 +229,15 @@ static void sql_delete_aclk_table_list(char *host_guid)
     buffer_sprintf(sql,"SELECT 'drop '||type||' IF EXISTS '||name||';' FROM sqlite_schema " \
                         "WHERE name LIKE 'aclk_%%_%s' AND type IN ('table', 'trigger', 'index')", uuid_str);
 
-    rc = sqlite3_prepare_v2(db_meta, buffer_tostring(sql), -1, &res, 0);
-    if (rc != SQLITE_OK) {
-        error_report("Failed to prepare statement to clean up aclk tables");
+    if (!PREPARE_STATEMENT(db_meta, buffer_tostring(sql), &res))
         goto fail;
-    }
+
     buffer_flush(sql);
 
     while (sqlite3_step_monitored(res) == SQLITE_ROW)
         buffer_strcat(sql, (char *) sqlite3_column_text(res, 0));
 
-    rc = sqlite3_finalize(res);
-    if (unlikely(rc != SQLITE_OK))
-        error_report("Failed to finalize statement to clean up aclk tables, rc = %d", rc);
+    SQLITE_FINALIZE(res);
 
     rc = db_execute(db_meta, buffer_tostring(sql));
     if (unlikely(rc))
@@ -261,31 +251,24 @@ fail:
 static void sql_unregister_node(char *machine_guid)
 {
     int rc;
-    uuid_t host_uuid;
+    nd_uuid_t host_uuid;
 
     if (unlikely(!machine_guid))
         return;
 
     rc = uuid_parse(machine_guid, host_uuid);
-    if (rc) {
-        freez(machine_guid);
-        return;
-    }
+    if (rc)
+        goto skip;
 
     sqlite3_stmt *res = NULL;
 
-    rc = sqlite3_prepare_v2(db_meta, "UPDATE node_instance SET node_id = NULL WHERE host_id = @host_id", -1, &res, 0);
-    if (unlikely(rc != SQLITE_OK)) {
-        error_report("Failed to prepare statement to remove the host node id");
-        freez(machine_guid);
-        return;
-    }
-
-    rc = sqlite3_bind_blob(res, 1, &host_uuid, sizeof(host_uuid), SQLITE_STATIC);
-    if (unlikely(rc != SQLITE_OK)) {
-        error_report("Failed to bind host_id parameter to remove host node id");
+    if (!PREPARE_STATEMENT(db_meta, "UPDATE node_instance SET node_id = NULL WHERE host_id = @host_id", &res))
         goto skip;
-    }
+
+    int param = 0;
+    SQLITE_BIND_FAIL(done, sqlite3_bind_blob(res, ++param, &host_uuid, sizeof(host_uuid), SQLITE_STATIC));
+    param = 0;
+
     rc = sqlite3_step_monitored(res);
     if (unlikely(rc != SQLITE_DONE)) {
         error_report("Failed to execute command to remove host node id");
@@ -295,9 +278,10 @@ static void sql_unregister_node(char *machine_guid)
        machine_guid = NULL;
     }
 
+done:
+    REPORT_BIND_FAIL(res, param);
+    SQLITE_FINALIZE(res);
 skip:
-    if (unlikely(sqlite3_finalize(res) != SQLITE_OK))
-        error_report("Failed to finalize statement to remove host node id");
     freez(machine_guid);
 }
 
@@ -351,13 +335,11 @@ static void sql_maint_aclk_sync_database_all(void)
 static int aclk_config_parameters(void *data __maybe_unused, int argc __maybe_unused, char **argv, char **column __maybe_unused)
 {
     char uuid_str[UUID_STR_LEN];
-    uuid_unparse_lower(*((uuid_t *) argv[0]), uuid_str);
+    uuid_unparse_lower(*((nd_uuid_t *) argv[0]), uuid_str);
 
     RRDHOST *host = rrdhost_find_by_guid(uuid_str);
-    if (host == localhost)
-        return 0;
-
-    sql_create_aclk_table(host, (uuid_t *) argv[0], (uuid_t *) argv[1]);
+    if (host != localhost)
+        sql_create_aclk_table(host, (nd_uuid_t *) argv[0], (nd_uuid_t *) argv[1]);
     return 0;
 }
 
@@ -394,7 +376,7 @@ static void timer_cb(uv_timer_t *handle)
 static void aclk_synchronization(void *arg __maybe_unused)
 {
     struct aclk_sync_config_s *config = arg;
-    uv_thread_set_name_np(config->thread,  "ACLKSYNC");
+    uv_thread_set_name_np("ACLKSYNC");
     worker_register("ACLKSYNC");
     service_register(SERVICE_THREAD_TYPE_EVENT_LOOP, NULL, NULL, NULL, true);
 
@@ -507,7 +489,7 @@ static void aclk_synchronization_init(void)
 
 // -------------------------------------------------------------
 
-void sql_create_aclk_table(RRDHOST *host __maybe_unused, uuid_t *host_uuid __maybe_unused, uuid_t *node_id __maybe_unused)
+void sql_create_aclk_table(RRDHOST *host __maybe_unused, nd_uuid_t *host_uuid __maybe_unused, nd_uuid_t *node_id __maybe_unused)
 {
 #ifdef ENABLE_ACLK
     char uuid_str[UUID_STR_LEN];
@@ -578,13 +560,7 @@ void sql_aclk_sync_init(void)
     char *err_msg = NULL;
     int rc;
 
-    if (unlikely(!db_meta)) {
-        if (default_rrd_memory_mode != RRD_MEMORY_MODE_DBENGINE) {
-            return;
-        }
-        error_report("Database has not been initialized");
-        return;
-    }
+    REQUIRE_DB(db_meta);
 
     netdata_log_info("Creating archived hosts");
     int number_of_children = 0;
