@@ -80,40 +80,59 @@ int configure_sqlite_database(sqlite3 *database, int target_version, const char
     char buf[1024 + 1] = "";
     const char *list[2] = { buf, NULL };
 
+    const char *def_auto_vacuum = "INCREMENTAL";
+    const char *def_synchronous = "NORMAL";
+    const char *def_journal_mode = "WAL";
+    const char *def_temp_store = "MEMORY";
+    long long def_journal_size_limit = 16777216;
+    long long def_cache_size = -2000;
+
     // https://www.sqlite.org/pragma.html#pragma_auto_vacuum
     // PRAGMA schema.auto_vacuum = 0 | NONE | 1 | FULL | 2 | INCREMENTAL;
-    snprintfz(buf, sizeof(buf) - 1, "PRAGMA auto_vacuum=%s", config_get(CONFIG_SECTION_SQLITE, "auto vacuum", "INCREMENTAL"));
+    snprintfz(buf, sizeof(buf) - 1, "PRAGMA auto_vacuum=%s", def_auto_vacuum);
+    if (config_exists(CONFIG_SECTION_SQLITE, "auto vacuum"))
+        snprintfz(buf, sizeof(buf) - 1, "PRAGMA auto_vacuum=%s",config_get(CONFIG_SECTION_SQLITE, "auto vacuum", def_auto_vacuum));
     if (init_database_batch(database, list, description))
         return 1;
 
     // https://www.sqlite.org/pragma.html#pragma_synchronous
     // PRAGMA schema.synchronous = 0 | OFF | 1 | NORMAL | 2 | FULL | 3 | EXTRA;
-    snprintfz(buf, sizeof(buf) - 1, "PRAGMA synchronous=%s", config_get(CONFIG_SECTION_SQLITE, "synchronous", "NORMAL"));
+    snprintfz(buf, sizeof(buf) - 1, "PRAGMA synchronous=%s", def_synchronous);
+    if (config_exists(CONFIG_SECTION_SQLITE, "synchronous"))
+        snprintfz(buf, sizeof(buf) - 1, "PRAGMA synchronous=%s", config_get(CONFIG_SECTION_SQLITE, "synchronous", def_synchronous));
     if (init_database_batch(database, list, description))
         return 1;
 
     // https://www.sqlite.org/pragma.html#pragma_journal_mode
     // PRAGMA schema.journal_mode = DELETE | TRUNCATE | PERSIST | MEMORY | WAL | OFF
-    snprintfz(buf, sizeof(buf) - 1, "PRAGMA journal_mode=%s", config_get(CONFIG_SECTION_SQLITE, "journal mode", "WAL"));
+    snprintfz(buf, sizeof(buf) - 1, "PRAGMA journal_mode=%s", def_journal_mode);
+    if (config_exists(CONFIG_SECTION_SQLITE, "journal mode"))
+        snprintfz(buf, sizeof(buf) - 1, "PRAGMA journal_mode=%s", config_get(CONFIG_SECTION_SQLITE, "journal mode", def_journal_mode));
     if (init_database_batch(database, list, description))
         return 1;
 
     // https://www.sqlite.org/pragma.html#pragma_temp_store
     // PRAGMA temp_store = 0 | DEFAULT | 1 | FILE | 2 | MEMORY;
-    snprintfz(buf, sizeof(buf) - 1, "PRAGMA temp_store=%s", config_get(CONFIG_SECTION_SQLITE, "temp store", "MEMORY"));
+    snprintfz(buf, sizeof(buf) - 1, "PRAGMA temp_store=%s", def_temp_store);
+    if (config_exists(CONFIG_SECTION_SQLITE, "temp store"))
+        snprintfz(buf, sizeof(buf) - 1, "PRAGMA temp_store=%s", config_get(CONFIG_SECTION_SQLITE, "temp store", def_temp_store));
     if (init_database_batch(database, list, description))
         return 1;
 
     // https://www.sqlite.org/pragma.html#pragma_journal_size_limit
     // PRAGMA schema.journal_size_limit = N ;
-    snprintfz(buf, sizeof(buf) - 1, "PRAGMA journal_size_limit=%lld", config_get_number(CONFIG_SECTION_SQLITE, "journal size limit", 16777216));
+    snprintfz(buf, sizeof(buf) - 1, "PRAGMA journal_size_limit=%lld", def_journal_size_limit);
+    if (config_exists(CONFIG_SECTION_SQLITE, "journal size limit"))
+        snprintfz(buf, sizeof(buf) - 1, "PRAGMA journal_size_limit=%lld", config_get_number(CONFIG_SECTION_SQLITE, "journal size limit", def_journal_size_limit));
     if (init_database_batch(database, list, description))
         return 1;
 
     // https://www.sqlite.org/pragma.html#pragma_cache_size
     // PRAGMA schema.cache_size = pages;
     // PRAGMA schema.cache_size = -kibibytes;
-    snprintfz(buf, sizeof(buf) - 1, "PRAGMA cache_size=%lld", config_get_number(CONFIG_SECTION_SQLITE, "cache size", -2000));
+    snprintfz(buf, sizeof(buf) - 1, "PRAGMA cache_size=%lld", def_cache_size);
+    if (config_exists(CONFIG_SECTION_SQLITE, "cache size"))
+        snprintfz(buf, sizeof(buf) - 1, "PRAGMA cache_size=%lld", config_get_number(CONFIG_SECTION_SQLITE, "cache size", def_cache_size));
     if (init_database_batch(database, list, description))
         return 1;
 
@@ -279,18 +298,12 @@ void sql_drop_table(const char *table)
 static int get_pragma_value(sqlite3 *database, const char *sql)
 {
     sqlite3_stmt *res = NULL;
-    int rc = sqlite3_prepare_v2(database, sql, -1, &res, 0);
-    if (unlikely(rc != SQLITE_OK))
-        return -1;
-
     int result = -1;
-    rc = sqlite3_step_monitored(res);
-    if (likely(rc == SQLITE_ROW))
-        result = sqlite3_column_int(res, 0);
-
-    rc = sqlite3_finalize(res);
-    (void) rc;
-
+    if (PREPARE_STATEMENT(database, sql, &res)) {
+        if (likely(sqlite3_step_monitored(res) == SQLITE_ROW))
+            result = sqlite3_column_int(res, 0);
+        SQLITE_FINALIZE(res);
+    }
     return result;
 }
 
@@ -346,6 +359,7 @@ void sql_close_database(sqlite3 *database, const char *database_name)
     rc = sqlite3_close_v2(database);
     if (unlikely(rc != SQLITE_OK))
         error_report("%s: Error while closing the sqlite database: rc %d, error \"%s\"", database_name, rc, sqlite3_errstr(rc));
+    database = NULL;
 }
 
 extern sqlite3 *db_context_meta;
@@ -358,6 +372,22 @@ void sqlite_close_databases(void)
     sql_close_database(db_meta, "METADATA");
 }
 
+uint64_t get_total_database_space(void)
+{
+    return 0;
+
+/*
+    if (!new_dbengine_defaults)
+        return 0;
+
+    uint64_t database_space = sqlite_get_meta_space() + sqlite_get_context_space();
+#ifdef ENABLE_ML
+    database_space +=  sqlite_get_ml_space();
+#endif
+    return database_space;
+*/
+}
+
 int sqlite_library_init(void)
 {
     initialize_thread_key_pool();
@@ -367,7 +397,11 @@ int sqlite_library_init(void)
     return (SQLITE_OK != rc);
 }
 
+SPINLOCK sqlite_spinlock = NETDATA_SPINLOCK_INITIALIZER;
+
 void sqlite_library_shutdown(void)
 {
+    spinlock_lock(&sqlite_spinlock);
     (void) sqlite3_shutdown();
+    spinlock_unlock(&sqlite_spinlock);
 }
