@@ -5,11 +5,14 @@ package jobmgr
 import (
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"log/slog"
+	"reflect"
 	"strconv"
 	"strings"
 	"time"
+	"unicode"
 
 	"github.com/netdata/netdata/go/go.d.plugin/agent/confgroup"
 	"github.com/netdata/netdata/go/go.d.plugin/agent/functions"
@@ -59,10 +62,10 @@ func dyncfgJobID(cfg confgroup.Config) string {
 }
 
 func dyncfgModCmds() string {
-	return "add schema enable disable test"
+	return "add schema enable disable test userconfig"
 }
 func dyncfgJobCmds(cfg confgroup.Config) string {
-	cmds := "schema get enable disable update restart test"
+	cmds := "schema get enable disable update restart test userconfig"
 	if isDyncfg(cfg) {
 		cmds += " remove"
 	}
@@ -107,8 +110,14 @@ func (m *Manager) dyncfgConfig(fn functions.Function) {
 	default:
 	}
 
+	//m.Infof("QQ FN: '%s'", fn)
+
 	action := strings.ToLower(fn.Args[1])
+
 	switch action {
+	case "userconfig":
+		m.dyncfgConfigUserconfig(fn)
+		return
 	case "test":
 		m.dyncfgConfigTest(fn)
 		return
@@ -127,8 +136,6 @@ func (m *Manager) dyncfgConfig(fn functions.Function) {
 func (m *Manager) dyncfgConfigExec(fn functions.Function) {
 	action := strings.ToLower(fn.Args[1])
 
-	//m.Infof("QQ FN(%s): '%s'", action, fn)
-
 	switch action {
 	case "test":
 		m.dyncfgConfigTest(fn)
@@ -154,6 +161,43 @@ func (m *Manager) dyncfgConfigExec(fn functions.Function) {
 	}
 }
 
+func (m *Manager) dyncfgConfigUserconfig(fn functions.Function) {
+	id := fn.Args[0]
+	jn := "test"
+	if len(fn.Args) > 2 {
+		jn = fn.Args[2]
+	}
+
+	mn, ok := extractModuleName(id)
+	if !ok {
+		m.Warningf("dyncfg: userconfig: could not extract module and job from id (%s)", id)
+		m.dyncfgRespf(fn, 400,
+			"Invalid ID format. Could not extract module and job name from ID. Provided ID: %s.", id)
+		return
+	}
+
+	creator, ok := m.Modules.Lookup(mn)
+	if !ok {
+		m.Warningf("dyncfg: userconfig: module %s not found", mn)
+		m.dyncfgRespf(fn, 404, "The specified module '%s' is not registered.", mn)
+		return
+	}
+
+	if creator.Config == nil || creator.Config() == nil {
+		m.Warningf("dyncfg: userconfig: module %s: configuration not found", mn)
+		m.dyncfgRespf(fn, 500, "Module %s does not provide configuration.", mn)
+		return
+	}
+
+	bs, err := userConfigFromPayload(creator.Config(), jn, fn)
+	if err != nil {
+		m.Warningf("dyncfg: userconfig: module %s: failed to create config from payload: %v", mn, err)
+		m.dyncfgRespf(fn, 400, "Invalid configuration format. Failed to create configuration from payload: %v.", err)
+	}
+
+	m.dyncfgRespPayloadYAML(fn, string(bs))
+}
+
 func (m *Manager) dyncfgConfigTest(fn functions.Function) {
 	id := fn.Args[0]
 	mn, ok := extractModuleName(id)
@@ -164,6 +208,17 @@ func (m *Manager) dyncfgConfigTest(fn functions.Function) {
 		return
 	}
 
+	jn := "test"
+	if len(fn.Args) > 2 {
+		jn = fn.Args[2]
+	}
+
+	if err := validateJobName(jn); err != nil {
+		m.Warningf("dyncfg: test: module %s: unacceptable job name '%s': %v", mn, jn, err)
+		m.dyncfgRespf(fn, 400, "Unacceptable job name '%s': %v.", jn, err)
+		return
+	}
+
 	creator, ok := m.Modules.Lookup(mn)
 	if !ok {
 		m.Warningf("dyncfg: test: module %s not found", mn)
@@ -178,8 +233,16 @@ func (m *Manager) dyncfgConfigTest(fn functions.Function) {
 		return
 	}
 
+	if cfg.Vnode() != "" {
+		if _, ok := m.Vnodes.Lookup(cfg.Vnode()); !ok {
+			m.Warningf("dyncfg: test: module %s: vnode %s not found", mn, cfg.Vnode())
+			m.dyncfgRespf(fn, 400, "The specified vnode '%s' is not registered.", cfg.Vnode())
+			return
+		}
+	}
+
 	cfg.SetModule(mn)
-	cfg.SetName("test")
+	cfg.SetName(jn)
 
 	job := creator.Create()
 
@@ -230,7 +293,7 @@ func (m *Manager) dyncfgConfigSchema(fn functions.Function) {
 		return
 	}
 
-	m.dyncfgRespPayload(fn, mod.JobConfigSchema)
+	m.dyncfgRespPayloadJSON(fn, mod.JobConfigSchema)
 }
 
 func (m *Manager) dyncfgConfigGet(fn functions.Function) {
@@ -279,7 +342,7 @@ func (m *Manager) dyncfgConfigGet(fn functions.Function) {
 		return
 	}
 
-	m.dyncfgRespPayload(fn, string(bs))
+	m.dyncfgRespPayloadJSON(fn, string(bs))
 }
 
 func (m *Manager) dyncfgConfigRestart(fn functions.Function) {
@@ -367,6 +430,11 @@ func (m *Manager) dyncfgConfigEnable(fn functions.Function) {
 
 	switch ecfg.status {
 	case dyncfgAccepted, dyncfgDisabled, dyncfgFailed:
+	case dyncfgRunning:
+		// non-dyncfg update triggers enable/disable
+		m.dyncfgRespf(fn, 200, "")
+		m.dyncfgJobStatus(ecfg.cfg, ecfg.status)
+		return
 	default:
 		m.Warningf("dyncfg: enable: module %s job %s: enabling not allowed in %s state", mn, jn, ecfg.status)
 		m.dyncfgRespf(fn, 405, "Enabling data collection job is not allowed in '%s' state.", ecfg.status)
@@ -487,6 +555,12 @@ func (m *Manager) dyncfgConfigAdd(fn functions.Function) {
 		return
 	}
 
+	if err := validateJobName(jn); err != nil {
+		m.Warningf("dyncfg: add: module %s: unacceptable job name '%s': %v", mn, jn, err)
+		m.dyncfgRespf(fn, 400, "Unacceptable job name '%s': %v.", jn, err)
+		return
+	}
+
 	cfg, err := configFromPayload(fn)
 	if err != nil {
 		m.Warningf("dyncfg: add: module %s job %s: failed to create config from payload: %v", mn, jn, err)
@@ -652,9 +726,17 @@ func (m *Manager) dyncfgSetConfigMeta(cfg confgroup.Config, module, name string)
 	}
 }
 
-func (m *Manager) dyncfgRespPayload(fn functions.Function, payload string) {
+func (m *Manager) dyncfgRespPayloadJSON(fn functions.Function, payload string) {
+	m.dyncfgRespPayload(fn, payload, "application/json")
+}
+
+func (m *Manager) dyncfgRespPayloadYAML(fn functions.Function, payload string) {
+	m.dyncfgRespPayload(fn, payload, "application/yaml")
+}
+
+func (m *Manager) dyncfgRespPayload(fn functions.Function, payload string, contentType string) {
 	ts := strconv.FormatInt(time.Now().Unix(), 10)
-	m.api.FUNCRESULT(fn.UID, "application/json", payload, "200", ts)
+	m.api.FUNCRESULT(fn.UID, contentType, payload, "200", ts)
 }
 
 func (m *Manager) dyncfgRespf(fn functions.Function, code int, msgf string, a ...any) {
@@ -672,6 +754,45 @@ func (m *Manager) dyncfgRespf(fn functions.Function, code int, msgf string, a ..
 	m.api.FUNCRESULT(fn.UID, "application/json", string(bs), strconv.Itoa(code), ts)
 }
 
+func userConfigFromPayload(cfg any, jobName string, fn functions.Function) ([]byte, error) {
+	if v := reflect.ValueOf(cfg); v.Kind() != reflect.Ptr || v.IsNil() {
+		return nil, fmt.Errorf("invalid config: expected a pointer to a struct, got a %s", v.Type())
+	}
+
+	if fn.ContentType == "application/json" {
+		if err := json.Unmarshal(fn.Payload, cfg); err != nil {
+			return nil, err
+		}
+	} else {
+		if err := yaml.Unmarshal(fn.Payload, cfg); err != nil {
+			return nil, err
+		}
+	}
+
+	bs, err := yaml.Marshal(cfg)
+	if err != nil {
+		return nil, err
+	}
+
+	var yms yaml.MapSlice
+	if err := yaml.Unmarshal(bs, &yms); err != nil {
+		return nil, err
+	}
+
+	yms = append([]yaml.MapItem{{Key: "name", Value: jobName}}, yms...)
+
+	v := map[string]any{
+		"jobs": []any{yms},
+	}
+
+	bs, err = yaml.Marshal(v)
+	if err != nil {
+		return nil, err
+	}
+
+	return bs, nil
+}
+
 func configFromPayload(fn functions.Function) (confgroup.Config, error) {
 	var cfg confgroup.Config
 
@@ -716,3 +837,16 @@ func extractJobName(id string) (string, bool) {
 	}
 	return id[i+1:], true
 }
+
+func validateJobName(jobName string) error {
+	for _, r := range jobName {
+		if unicode.IsSpace(r) {
+			return errors.New("contains spaces")
+		}
+		switch r {
+		case '.', ':':
+			return fmt.Errorf("contains '%c'", r)
+		}
+	}
+	return nil
+}
