@@ -672,7 +672,7 @@ static int rrdpush_http_upgrade_prelude(RRDHOST *host, struct sender_state *s) {
     rbuf_push(buf, http, bytes);
 
     http_parse_ctx ctx;
-    http_parse_ctx_create(&ctx);
+    http_parse_ctx_create(&ctx, HTTP_PARSE_INITIAL);
     ctx.flags |= HTTP_PARSE_FLAG_DONT_WAIT_FOR_CONTENT;
 
     int rc;
@@ -883,9 +883,8 @@ static bool rrdpush_sender_thread_connect_to_parent(RRDHOST *host, int default_p
         return false;
     }
     
-    ssize_t bytes, len = (ssize_t)strlen(http);
-
-    bytes = send_timeout(
+    ssize_t len = (ssize_t)strlen(http);
+    ssize_t bytes = send_timeout(
 #ifdef ENABLE_HTTPS
         &host->sender->ssl,
 #endif
@@ -1015,8 +1014,10 @@ static bool attempt_to_connect(struct sender_state *state) {
     usec_t now_ut = now_monotonic_usec();
     usec_t end_ut = now_ut + USEC_PER_SEC * state->reconnect_delay;
     while(now_ut < end_ut) {
-        netdata_thread_testcancel();
-        sleep_usec(500 * USEC_PER_MS); // seconds
+        if(nd_thread_signaled_to_cancel())
+            return false;
+
+        sleep_usec(100 * USEC_PER_MS); // seconds
         now_ut = now_monotonic_usec();
     }
 
@@ -1227,12 +1228,23 @@ void execute_commands(struct sender_state *s) {
     ND_LOG_STACK_PUSH(lgs);
 
     char *start = s->read_buffer, *end = &s->read_buffer[s->read_len], *newline;
-    *end = 0;
-    while( start < end && (newline = strchr(start, '\n')) ) {
+    *end = '\0';
+    for( ; start < end ; start = newline + 1) {
+        newline = strchr(start, '\n');
+
+        if(!newline) {
+            if(s->functions.intercept_input) {
+                buffer_strcat(s->functions.payload, start);
+                start = end;
+            }
+            break;
+        }
+
+        *newline = '\0';
         s->line.count++;
 
         if(s->functions.intercept_input) {
-            if(strcmp(start, PLUGINSD_CALL_FUNCTION_PAYLOAD_END "\n") == 0) {
+            if(strcmp(start, PLUGINSD_CALL_FUNCTION_PAYLOAD_END) == 0) {
                 execute_commands_function(s,
                     PLUGINSD_CALL_FUNCTION_PAYLOAD_END,
                                           s->functions.transaction, s->functions.timeout_s,
@@ -1241,14 +1253,14 @@ void execute_commands(struct sender_state *s) {
 
                 cleanup_intercepting_input(s);
             }
-            else
+            else {
                 buffer_strcat(s->functions.payload, start);
+                buffer_fast_charcat(s->functions.payload, '\n');
+            }
 
-            start = newline + 1;
             continue;
         }
 
-        *newline = '\0';
         s->line.num_words = quoted_strings_splitter_pluginsd(start, s->line.words, PLUGINSD_MAX_WORDS);
         const char *command = get_word(s->line.words, s->line.num_words, 0);
 
@@ -1327,7 +1339,6 @@ void execute_commands(struct sender_state *s) {
 
         line_splitter_reset(&s->line);
         worker_is_busy(WORKER_SENDER_JOB_EXECUTE);
-        start = newline + 1;
     }
 
     if (start < end) {
@@ -1386,7 +1397,7 @@ static bool rrdpush_sender_pipe_close(RRDHOST *host, int *pipe_fds, bool reopen)
 }
 
 void rrdpush_signal_sender_to_wake_up(struct sender_state *s) {
-    if(unlikely(s->tid == gettid()))
+    if(unlikely(s->tid == gettid_cached()))
         return;
 
     RRDHOST *host = s->host;
@@ -1409,7 +1420,7 @@ static bool rrdhost_set_sender(RRDHOST *host) {
         rrdhost_flag_clear(host, RRDHOST_FLAG_RRDPUSH_SENDER_CONNECTED | RRDHOST_FLAG_RRDPUSH_SENDER_READY_4_METRICS);
         rrdhost_flag_set(host, RRDHOST_FLAG_RRDPUSH_SENDER_SPAWN);
         host->rrdpush_sender_connection_counter++;
-        host->sender->tid = gettid();
+        host->sender->tid = gettid_cached();
         host->sender->last_state_since_t = now_realtime_sec();
         host->sender->exit.reason = STREAM_HANDSHAKE_NEVER;
         ret = true;
@@ -1424,7 +1435,7 @@ static bool rrdhost_set_sender(RRDHOST *host) {
 static void rrdhost_clear_sender___while_having_sender_mutex(RRDHOST *host) {
     if(unlikely(!host->sender)) return;
 
-    if(host->sender->tid == gettid()) {
+    if(host->sender->tid == gettid_cached()) {
         host->sender->tid = 0;
         host->sender->exit.shutdown = false;
         rrdhost_flag_clear(host, RRDHOST_FLAG_RRDPUSH_SENDER_SPAWN | RRDHOST_FLAG_RRDPUSH_SENDER_CONNECTED | RRDHOST_FLAG_RRDPUSH_SENDER_READY_4_METRICS);
@@ -1439,8 +1450,11 @@ static void rrdhost_clear_sender___while_having_sender_mutex(RRDHOST *host) {
 }
 
 static bool rrdhost_sender_should_exit(struct sender_state *s) {
-    // check for outstanding cancellation requests
-    netdata_thread_testcancel();
+    if(unlikely(nd_thread_signaled_to_cancel())) {
+        if(!s->exit.reason)
+            s->exit.reason = STREAM_HANDSHAKE_DISCONNECT_SHUTDOWN;
+        return true;
+    }
 
     if(unlikely(!service_running(SERVICE_STREAMING))) {
         if(!s->exit.reason)
@@ -1469,8 +1483,10 @@ static bool rrdhost_sender_should_exit(struct sender_state *s) {
     return false;
 }
 
-static void rrdpush_sender_thread_cleanup_callback(void *ptr) {
-    struct rrdpush_sender_thread_data *s = ptr;
+static void rrdpush_sender_thread_cleanup_callback(void *pptr) {
+    struct rrdpush_sender_thread_data *s = CLEANUP_FUNCTION_GET_PTR(pptr);
+    if(!s) return;
+
     worker_unregister();
 
     RRDHOST *host = s->host;
@@ -1615,19 +1631,19 @@ void *rrdpush_sender_thread(void *ptr) {
        !*s->host->rrdpush_send_destination || !s->host->rrdpush_send_api_key ||
        !*s->host->rrdpush_send_api_key) {
         netdata_log_error("STREAM %s [send]: thread created (task id %d), but host has streaming disabled.",
-              rrdhost_hostname(s->host), gettid());
+              rrdhost_hostname(s->host), gettid_cached());
         return NULL;
     }
 
     if(!rrdhost_set_sender(s->host)) {
         netdata_log_error("STREAM %s [send]: thread created (task id %d), but there is another sender running for this host.",
-              rrdhost_hostname(s->host), gettid());
+              rrdhost_hostname(s->host), gettid_cached());
         return NULL;
     }
 
     rrdpush_initialize_ssl_ctx(s->host);
 
-    netdata_log_info("STREAM %s [send]: thread created (task id %d)", rrdhost_hostname(s->host), gettid());
+    netdata_log_info("STREAM %s [send]: thread created (task id %d)", rrdhost_hostname(s->host), gettid_cached());
 
     s->timeout = (int)appconfig_get_number(
         &stream_config, CONFIG_SECTION_STREAM, "timeout seconds", 600);
@@ -1670,7 +1686,7 @@ void *rrdpush_sender_thread(void *ptr) {
     thread_data->pipe_buffer = mallocz(pipe_buffer_size);
     thread_data->host = s->host;
 
-    netdata_thread_cleanup_push(rrdpush_sender_thread_cleanup_callback, thread_data);
+    CLEANUP_FUNCTION_REGISTER(rrdpush_sender_thread_cleanup_callback) cleanup_ptr = thread_data;
 
     size_t iterations = 0;
     time_t now_s = now_monotonic_sec();
@@ -1794,7 +1810,6 @@ void *rrdpush_sender_thread(void *ptr) {
 
         // Spurious wake-ups without error - loop again
         if (poll_rc == 0 || ((poll_rc == -1) && (errno == EAGAIN || errno == EINTR))) {
-            netdata_thread_testcancel();
             netdata_log_debug(D_STREAM, "Spurious wakeup");
             now_s = now_monotonic_sec();
             continue;
@@ -1888,6 +1903,5 @@ void *rrdpush_sender_thread(void *ptr) {
         worker_set_metric(WORKER_SENDER_JOB_REPLAY_DICT_SIZE, (NETDATA_DOUBLE) dictionary_entries(s->replication.requests));
     }
 
-    netdata_thread_cleanup_pop(1);
     return NULL;
 }
